<div id='header' align="center">
  <img width="200" alt="Screenshot 2024-08-10 at 11 44 54 AM" src="https://github.com/user-attachments/assets/62e3af42-6984-4e1c-9ddc-3f6115573e01">
  <br>
  <br>
  <div id="badges">
    <a href="your-linkedin-URL" style="text-decoration: none;">
      <img src="https://img.shields.io/badge/LinkedIn-blue?style=for-the-badge&logo=linkedin&logoColor=white" alt="LinkedIn Badge"/>
    </a>
    <a href="https://github.com/rohannair2022/Weedout/" style="text-decoration: none;">
      <img src="https://img.shields.io/badge/github-black?style=for-the-badge&logo=github&logoColor=white" alt="Github Badge"/>
    </a>
  </div>
  <div id ="badges">
    <a href="https://pypi.org/project/weedout/" style="text-decoration: none;">
      <img src="https://img.shields.io/badge/pypi-green?style=for-the-badge&logo=python&logoColor=white" alt="Python Badge"/>
    </a>
  </div>
</div>

## What is it?

**Weedout** is an open-source python package that makes data preparation and visualization easier for csv datasets. Weedout's cutting-edge pipeline will assist you in cleaning your data, from generating data frames all the way to encoding and imputing. By automating the laborious tasks of feature engineering, data transformation, and cleaning, it allows you to concentrate on model building. Whether you are working with time series or cross-sectional data, Weedout has the tools you need to effectively and efficiently prepare your data. Unit tests have been utilized to verify each function and pipeline separately.

The link to our **LinkedIn page** is: [Weedout LinkedIn](https://www.linkedin.com/company/weedoutdata/?viewAsMember=true).

## How to install Weedout

You can directly install weedout from the PyPi library using the command:

```bash
# PyPi

pip install weedout
```

You can also install it locally on your PC after cloning the repo using the following command:

```bash
#Local Install

pip install setuptools wheel twine

python setup.py sdist bdist_wheel

# Replace the current version of weedout in version:

pip install dist/weedout-<version>-py3-none-any.whl
```

## How can you contribute to Weedout?

There are multiple different ways one can contribute to weedout's open source package. We would really appreciate any kind of contribution.

1. Report Bugs:
   - Open an Issue and select the Bug report template.
   - Fill out the template and submit the issue. Note you can assign the task to yourself if you want to fix the issue.
   - If you do want to fix the bug. You can fork the repo, make the changes and issue a pull request.
2. Enhance Exisiting Features:
   - For enchancing existing features you can make direct pull requests.
3. Create New Features:
   - Unlike exisiting features. You will first have to assign an issue with the feature template that will be approved by the core members.
   - Upon apporval, you can then make a pull request to add your new feature in.
